[clutter-gst] video-sink* examples: Port to gstreamer 1.0.



commit 48d8abac8cf1d5bf7ad74e8795a2b844e117e587
Author: Andre Moreira Magalhaes (andrunko) <andre magalhaes collabora co uk>
Date:   Wed Aug 22 12:05:32 2012 -0300

    video-sink* examples: Port to gstreamer 1.0.

 examples/video-sink-navigation.c |    6 +++---
 examples/video-sink.c            |    4 ++--
 2 files changed, 5 insertions(+), 5 deletions(-)
---
diff --git a/examples/video-sink-navigation.c b/examples/video-sink-navigation.c
index 3f91ca3..87f0795 100644
--- a/examples/video-sink-navigation.c
+++ b/examples/video-sink-navigation.c
@@ -4,7 +4,7 @@
  * GStreamer integration library for Clutter.
  *
  * video-sink.c - A small example around the videotestsrc ! capsfilter !
  *                navigationtest ! ffmpegcolorspace ! cluttersink pipeline.
  *
  * Copyright (C) 2007,2008 OpenedHand
  *
@@ -114,10 +114,10 @@ main (int argc, char *argv[])
   pipeline = GST_PIPELINE(gst_pipeline_new (NULL));
 
   src = gst_parse_launch ("videotestsrc", NULL);
-  filter = gst_parse_launch ("capsfilter caps=video/x-raw-yuv,pixel-aspect-ratio=1/4", NULL);
+  filter = gst_parse_launch ("capsfilter caps=video/x-raw,pixel-aspect-ratio=1/4", NULL);
 
   test = gst_element_factory_make ("navigationtest", NULL);
-  colorspace = gst_element_factory_make ("ffmpegcolorspace", NULL);
+  colorspace = gst_element_factory_make ("videoconvert", NULL);
   sink = gst_element_factory_make ("cluttersink", NULL);
   g_object_set (sink, "texture", CLUTTER_TEXTURE (texture), NULL);
 
@@ -4,7 +4,7 @@
  *
  * video-sink.c - A small example around the videotestsrc ! capsfilter !
- *                navigationtest ! ffmpegcolorspace ! cluttersink pipeline.
+ *                navigationtest ! videoconvert ! cluttersink pipeline.
  *
  * Copyright (C) 2007,2008 OpenedHand
diff --git a/examples/video-sink.c b/examples/video-sink.c
index 877f2d8..b0e13f3 100644
--- a/examples/video-sink.c
+++ b/examples/video-sink.c
@@ -4,7 +4,7 @@
  * GStreamer integration library for Clutter.
  *
  * video-sink.c - A small example around the videotestsrc ! warptv !
  *                ffmpegcolorspace ! cluttersink pipeline.
  *
  * Copyright (C) 2007,2008 OpenedHand
  *
@@ -112,7 +112,7 @@ main (int argc, char *argv[])
 
   src = gst_element_factory_make ("videotestsrc", NULL);
   warp = gst_element_factory_make ("warptv", NULL);
-  colorspace = gst_element_factory_make ("ffmpegcolorspace", NULL);
+  colorspace = gst_element_factory_make ("videoconvert", NULL);
   sink = gst_element_factory_make ("cluttersink", NULL);
   g_object_set (sink, "texture", CLUTTER_TEXTURE (texture), NULL);
 
@@ -4,7 +4,7 @@
  *
  * video-sink.c - A small example around the videotestsrc ! warptv !
- *                ffmpegcolorspace ! cluttersink pipeline.
+ *                videoconvert ! cluttersink pipeline.
  *
  * Copyright (C) 2007,2008 OpenedHand



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]